/*
 * mvs-tmdb-image.h
 *
 * This file is part of maevies
 * Copyright (C) 2010 Simón Pena <spenap@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 */

#ifndef _MVS_TMDB_IMAGE
#define _MVS_TMDB_IMAGE

#include <glib-object.h>

G_BEGIN_DECLS

#define MVS_TYPE_TMDB_IMAGE mvs_tmdb_image_get_type()
#define MVS_TMDB_IMAGE(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), MVS_TYPE_TMDB_IMAGE, MvsTmdbImage))
#define MVS_TMDB_IMAGE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), MVS_TYPE_TMDB_IMAGE, MvsTmdbImageClass))
#define MVS_IS_TMDB_IMAGE(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MVS_TYPE_TMDB_IMAGE))
#define MVS_IS_TMDB_IMAGE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), MVS_TYPE_TMDB_IMAGE))
#define MVS_TMDB_IMAGE_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), MVS_TYPE_TMDB_IMAGE, MvsTmdbImageClass))

typedef struct _MvsTmdbImagePrivate MvsTmdbImagePrivate;

typedef struct {
        GObject parent;

        /* <private> */
        MvsTmdbImagePrivate *priv;
} MvsTmdbImage;

typedef struct {
        GObjectClass parent_class;
} MvsTmdbImageClass;

enum {
        TYPE_FIELD,
        URL_FIELD,
        SIZE_FIELD,
        ID_FIELD,
        LAST_FIELD
};

static const gchar*
image_fields[LAST_FIELD] = { "type", "url", "size", "id" };

GType mvs_tmdb_image_get_type (void);

MvsTmdbImage* mvs_tmdb_image_new ();

gboolean
mvs_tmdb_image_set_imagetype (MvsTmdbImage *self, const gchar *type);

const gchar*
mvs_tmdb_image_get_imagetype (MvsTmdbImage *self);

gboolean
mvs_tmdb_image_set_url (MvsTmdbImage *self, const gchar *url);

const gchar*
mvs_tmdb_image_get_url (MvsTmdbImage *self);

gboolean
mvs_tmdb_image_set_size (MvsTmdbImage *self, const gchar *size);

const gchar*
mvs_tmdb_image_get_size (MvsTmdbImage *self);

gboolean
mvs_tmdb_image_set_width (MvsTmdbImage *self, gint width);

gint
mvs_tmdb_image_get_width (MvsTmdbImage *self);

gboolean
mvs_tmdb_image_set_height (MvsTmdbImage *self, gint height);

gint
mvs_tmdb_image_get_height (MvsTmdbImage *self);

gboolean
mvs_tmdb_image_set_id (MvsTmdbImage *self, const gchar *id);

const gchar*
mvs_tmdb_image_get_id (MvsTmdbImage *self);

void
mvs_tmdb_image_print (MvsTmdbImage *self);

G_END_DECLS

#endif /* _MVS_TMDB_IMAGE */
